@@ -1,12 +1,14 @@
 from .Protocol import Protocol
-from .States import MSIState as State
+from .Processor import Processor
+from .States import MOESIState as State
 from .Operations import MSIOps as Ops
 
 from .VI_Write_Through import VI
 from .MSI import MSI
 from .MESI import MESI
+from .MOESI import MOESI
 
-protocols = {"VI": VI, "MSI": MSI, "MESI": MESI}
+protocols = {"VI": VI, "MSI": MSI, "MESI": MESI, "MOESI": MOESI}
 
 simulation_parameters = {
     # "Reads",
@@ -27,7 +29,7 @@ class CacheCoherence:
             if len(instruction) == 3 and isinstance(instruction[2], str): instruction[2] = eval(instruction[2])
         protocol = protocols[_type](n_processors=n_processors, memory_content=memory_content)
         protocol.perform_instructions(instructions)
-        return protocol.get_api_results()
+        return protocol.api()
 
     @staticmethod
     def run_type(params, _type):
